Published work with lenstronomy — lenstronomy 1.9.1 documentation

# Published work with lenstronomy

In this section you can find the concept papers lenstronomy is based on the list of science publications that made use of lenstronomy. Please let the developers know when you publish a paper that made use of lenstronomy. We are happy to include your publication in this list.

## Core lenstronomy methodology and software publications

- lenstronomy: Multi-purpose gravitational lens modelling software package; Birrer & Amara 2018
    This is the lenstronomy software paper. Please cite this paper whenever you make use of lenstronomy. The paper gives a design overview and highlights some use cases.
- lenstronomy II: A gravitational lensing software ecosystem; Birrer et al. 2021
    JOSS software publication. Please cite this paper whenever you make use of lenstronomy.
- Gravitational Lens Modeling with Basis Sets; Birrer et al. 2015
    This is the method paper lenstronomy is primary based on. Please cite this paper whenever you publish results with lenstronomy by using Shapelet basis sets and/or the PSO and MCMC chain.

## Related software publications

- A versatile tool for cluster lensing source reconstruction. I. methodology and illustration on sources in the Hubble Frontier Field Cluster MACS J0717.5+3745; Yang et al. 2020a
    reconstructing the intrinsic size-mass relation of strongly lensed sources in clusters
- SLITronomy: towards a fully wavelet-based strong lensing inversion technique; Galan et al. 2020
    This is the method paper presenting SLITromomy, an improved version of the SLIT algorithm fully implemented and compatible with lenstronomy.
- deeplenstronomy: A dataset simulation package for strong gravitational lensing; Morgan et al. 2021
    Software to simulating large datasets for applying deep learning to strong gravitational lensing.

## Measuring the Hubble constant

- The mass-sheet degeneracy and time-delay cosmography: analysis of the strong lens RXJ1131-1231; Birrer et al. 2016
    This paper performs a cosmographic analysis and applies the Shapelet basis set scaling to marginalize over a major lensing degeneracy.
- H0LiCOW - IX. Cosmographic analysis of the doubly imaged quasar SDSS 1206+4332 and a new measurement of the Hubble constant; Birrer et al. 2019
    This paper performs a cosmographic analysis with power-law and composite models and covers a range in complexity in the source reconstruction
- Astrometric requirements for strong lensing time-delay cosmography; Birrer & Treu 2019
    Derives requirements on how well the image positions of time-variable sources has to be known to perform a time-delay cosmographic measurement
- H0LiCOW XIII. A 2.4% measurement of H0 from lensed quasars: 5.3σ tension between early and late-Universe probes; Wong et al. 2019
    Joint analysis of the six H0LiCOW lenses including the lenstronomy analysis of J1206
- STRIDES: A 3.9 per cent measurement of the Hubble constant from the strongly lensed system DES J0408-5354; Shajib et al. 2019
    most precise single lensing constraint on the Hubble constant. This analysis includes two source planes and three lensing planes
- TDCOSMO. I. An exploration of systematic uncertainties in the inference of H0 from time-delay cosmography Millon et al. 2020
    mock lenses to test accuracy on the recovered H0 value
- Lens modelling of the strongly lensed Type Ia supernova iPTF16geu Moertsell et al. 2020
    Modeling of a lensed supernova to measure the Hubble constant
- The impact of line-of-sight structures on measuring H0 with strong lensing time-delays Li, Becker and Dye 2020
    Point source position and time-delay modeling of quads
- TDCOSMO III: Dark matter substructure meets dark energy – the effects of (sub)halos on strong-lensing measurements of H0 Gilman, Birrer and Treu 2020
    Full line-of-sight halo rendering and time-delay analysis on mock images
- TDCOSMO IV: Hierarchical time-delay cosmography – joint inference of the Hubble constant and galaxy density profiles Birrer et al. 2020
    lenstronomy.Galkin for kinematics calculation that folds in the hierarchical analysis
- TDCOSMO V: strategies for precise and accurate measurements of the Hubble constant with strong lensing Birrer & Treu 2020
    lenstronomy.Galkin for kinematics calculation that folds in the hierarchical analysis for a forecast for future Hubble constant constraints
- Large-Scale Gravitational Lens Modeling with Bayesian Neural Networks for Accurate and Precise Inference of the Hubble Constant Park et al. 2020
    BBN lens model inference using lenstronomy through `baobab <https://github.com/jiwoncpark/baobab>`_ for training set generation.
- Improved time-delay lens modelling and H0 inference with transient sources Ding et al. 2021
    Simulations and models with and without lensed point sources to perform a time-delay cosmography analysis.
- Gravitational lensing H0 tension from ultralight axion galactic cores Blum & Teodori 2021
    Investigating the detectability of a cored component with mock imaging modeling and comparison of kinematic modeling.
- The Hubble constant from strongly lensed supernovae with standardizable magnifications Birrer, Dhawan, Shajib 2021
    Methodology and forecast to use standardizable magnifications to break the mass-sheet degeneracy and hierarchically measure H0.
- AI-driven spatio-temporal engine for finding gravitationally lensed supernovae Ramanah et al. 2021
    Simulated images with time series of lensed supernovae.

## Dark Matter substructure

- Lensing substructure quantification in RXJ1131-1231: a 2 keV lower bound on dark matter thermal relic mass; Birrer et al. 2017b
    This paper quantifies the substructure content of a lens by a sub-clump scanning procedure and the application of Approximate Bayesian Computing.
- Probing the nature of dark matter by forward modelling flux ratios in strong gravitational lenses; Gilman et al. 2018
- Probing dark matter structure down to 10**7 solar masses: flux ratio statistics in gravitational lenses with line-of-sight haloes; Gilman et al. 2019a
- Double dark matter vision: twice the number of compact-source lenses with narrow-line lensing and the WFC3 Grism; Nierenberg et al. 2019
- Warm dark matter chills out: constraints on the halo mass function and the free-streaming length of dark matter with 8 quadruple-image strong gravitational lenses; Gilman et al. 2019b
- Constraints on the mass-concentration relation of cold dark matter halos with 11 strong gravitational lenses; Gilman et al. 2019c
- Circumventing Lens Modeling to Detect Dark Matter Substructure in Strong Lens Images with Convolutional Neural Networks; Diaz Rivero & Dvorkin
- Dark Matter Subhalos, Strong Lensing and Machine Learning; Varma, Fairbairn, Figueroa
- Quantifying the Line-of-Sight Halo Contribution to the Dark Matter Convergence Power Spectrum from Strong Gravitational Lenses; Sengul et al. 2020
- Detecting Subhalos in Strong Gravitational Lens Images with Image Segmentation; Ostdiek et al. 2020a
- Extracting the Subhalo Mass Function from Strong Lens Images with Image Segmentation; Ostdiek et al. 2020b
- Strong lensing signatures of self-interacting dark matter in low-mass halos; Gilman et al. 2021

## Galaxy formation and evolution

- Massive elliptical galaxies at z∼0.2 are well described by stars and a Navarro-Frenk-White dark matter halo; Shajib et al. 2020a
    Automatized modeling of 23 SLACS lenses with dolphin, a lenstronomy wrapper
- High-resolution imaging follow-up of doubly imaged quasars; Shajib et al. 2020b
    Modeling of doubly lensed quasars from Keck Adaptive Optics data
- The evolution of the size-mass relation at z=1-3 derived from the complete Hubble Frontier Fields data set; Yang et al. 2020b
    reconstructing the intrinsic size-mass relation of strongly lensed sources in clusters

## Automatized Lens Modeling

- Is every strong lens model unhappy in its own way? Uniform modelling of a sample of 12 quadruply+ imaged quasars; Shajib et al. 2018
    This work presents a uniform modelling framework to model 13 quadruply lensed quasars in three HST bands.
- Hierarchical Inference With Bayesian Neural Networks: An Application to Strong Gravitational Lensing; Wagner-Carena et al. 2020
    This work conducts hierarchical inference of strongly-lensed systems with Bayesian neural networks.

## Quasar-host galaxy decomposition

- The mass relations between supermassive black holes and their host galaxies at 1<z<2 with HST-WFC3; Ding et al. 2019
    Quasar host galaxy decomposition at high redshift on HST imaging and marginalization over PSF uncertainties.
- Testing the Evolution of the Correlations between Supermassive Black Holes and their Host Galaxies using Eight Strongly Lensed Quasars; Ding et al. 2020
    Quasar host galaxy decomposition with lensed quasars.
- A local baseline of the black hole mass scaling relations for active galaxies. IV. Correlations between MBH and host galaxy σ, stellar mass, and luminosity; Bennert et al. 2021
    Detailed measurement of galaxy morphology, decomposing in spheroid, disk and bar, and central AGN
- The Sizes of Quasar Host Galaxies with the Hyper Suprime-Cam Subaru Strategic Program; Li et al. 2021
    Quasar-host decomposition of 5000 SDSS quasars

## Lensing of Gravitational Waves

- lensingGW: a Python package for lensing of gravitational waves; Pagano et al. 2020
    A Python package designed to handle both strong and microlensing of compact binaries and the related gravitational-wave signals.
- Localizing merging black holes with sub-arcsecond precision using gravitational-wave lensing; Hannuksela et al. 2020
    solving the lens equation with lenstronomy using lensingGW
- Lensing magnification: gravitational wave from coalescing stellar-mass binary black holes; Shan & Hu 2020
    lensing magnificatoin calculations
- Identifying Type-II Strongly-Lensed Gravitational-Wave Images in Third-Generation Gravitational-Wave Detectors; Y. Wang et al. 2021
    solving the lens equation
- Beyond the detector horizon: Forecasting gravitational-wave strong lensing; Renske et al. 2021
    computing image positions, time delays and magnifications for gravitational wave forecasting

## Theory papers

- Line-of-sight effects in strong lensing: putting theory into practice; Birrer et al. 2017a
    This paper formulates an effective parameterization of line-of-sight structure for strong gravitational lens modelling and applies this technique to an Einstein ring in the COSMOS field
- Cosmic Shear with Einstein Rings; Birrer et al. 2018a
    Forecast paper to measure cosmic shear with Einstein ring lenses. The forecast is made based on lenstronomy simulations.
- Unified lensing and kinematic analysis for any elliptical mass profile; Shajib 2019
    Provides a methodology to generalize the multi-Gaussian expansion to general elliptical mass and light profiles
- Gravitational lensing formalism in a curved arc basis: A continuous description of observables and degeneracies from the weak to the strong lensing regime; Birrer 2021
    Lensing formalism with curved arc distortion formalism. Link to code repository `here <https://github.com/sibirrer/curved_arcs>`_.

## Simulation products

- The LSST DESC DC2 Simulated Sky Survey; LSST Dark Energy Science Collaboration et al. 2020
    Strong lensing simulations produced by SLSprinkler utilizing lenstronomy functionalities
- The impact of mass map truncation on strong lensing simulations; Van de Vyvere et al. 2020
    Uses numerical integration to compute lensing quantities from projected mass maps from simulations.

## Large scale structure

- Combining strong and weak lensingestimates in the Cosmos field; Kuhn et al. 2020
    inferring cosmic shear with three strong lenses in the COSMOS field

## Lens finding

- On machine learning search for gravitational lenses; Khachatryan 2021
    simulating training sets for lens searches

## Others

- Predicting future astronomical events using deep learning; Singh et al.
    simulating strongly lensed galaxy merger pairs in time sequence